@@ -1,4 +1,4 @@
-/* $Id: calendar-conduit.c,v 1.23 2000/01/05 12:12:44 eskil Exp $ */
+/* $Id: calendar-conduit.c,v 1.27 2000/03/12 02:28:11 eskil Exp $ */
 
 #include <glib.h>
 #include <gnome.h>
@@ -30,6 +30,8 @@
 
 #include "calendar-conduit.h"
 
+#include <unistd.h>
+
 int debug_alarms = 0;  /* needed to satisfy some other part of gncal */
 /* Default values for alarms */ /* needed to satisfy some other part of gncal */
 CalendarAlarm alarm_defaults[4] = {
@@ -43,7 +45,8 @@ GnomePilotConduit * conduit_get_gpilot_conduit (guint32);
 void conduit_destroy_gpilot_conduit (GnomePilotConduit*);
 void local_record_from_icalobject(GCalLocalRecord *local,iCalObject *obj); 
 
-#define CONDUIT_VERSION "0.8.11"
+#define CONDUIT_VERSION "0.8.12"
+
 #ifdef G_LOG_DOMAIN
 #undef G_LOG_DOMAIN
 #endif
@@ -75,15 +78,31 @@ static int
 start_calendar_server (GnomePilotConduitStandardAbs *conduit,
 		       GCalConduitContext *ctxt) 
 {
-	
+	gint tries;
+
 	g_return_val_if_fail(conduit!=NULL,-2);
 	g_return_val_if_fail(ctxt!=NULL,-2);
-	
-	ctxt->calendar = goad_server_activate_with_id (NULL, 
-						       "IDL:GNOME:Calendar:Repository:1.0",
-						       0, NULL);
+
+	/* This is eerie, sometimes the gnomecal doesn't start, so e
+           try three more times, sepped by 1 sec */
+	for (tries = 3; tries; tries--) {
+		ctxt->calendar = goad_server_activate_with_repo_id (
+			NULL, 
+			"IDL:Gnome/Calendar/Repository:1.0",
+			0, 
+			NULL);
+		if (ctxt->calendar == CORBA_OBJECT_NIL) {
+			sleep (1);
+			g_message("trying(%d)",tries);
+			continue;
+		} else {
+			break;
+		}
+	}
 	if (ctxt->calendar == CORBA_OBJECT_NIL) {
-		g_warning ("Can not communicate with GnomeCalendar server");
+		/* lots of people have problems with gnomecal not starting up... 
+		   so we try again... */
+		g_message("Could not start gnomecal server");
 		return -1;
 	}
   
@@ -392,7 +411,7 @@ ical_from_remote_record(GnomePilotConduitStandardAbs *conduit,
 	/*
 	 * Recurrence
 	 */
-	if (a.repeatFrequency){
+	if (a.repeatFrequency && a.repeatType != repeatNone){
 		obj->recur = g_new0 (Recurrence, 1);
 		
 		switch (a.repeatType){
@@ -435,15 +454,18 @@ ical_from_remote_record(GnomePilotConduitStandardAbs *conduit,
 		case repeatYearly:
 			obj->recur->type = RECUR_YEARLY_BY_DAY;
 			break;
-
 		default:
+			g_warning("Unknown repeat type, malformed calendar ? (type was %d)",a.repeatType);
 			g_assert_not_reached();
 		}
 
 		if (a.repeatForever)
 			obj->recur->duration = 0;
-		else
-			obj->recur->_enddate = mktime (&a.repeatEnd);
+		else {
+			/* Add one day (86400 secs to make gnomecal see the end-on-date */
+			g_message("repeatend is %d/%d/%d",a.repeatEnd.tm_mday,a.repeatEnd.tm_mon,1900+a.repeatEnd.tm_year);
+			obj->recur->_enddate = mktime (&a.repeatEnd)+86400;
+		}
 
 		obj->recur->interval = a.repeatFrequency;
 	}
@@ -999,8 +1021,9 @@ transmit (GnomePilotConduitStandardAbs *conduit,
 		if (local->ical->recur->duration == 0) {
 			local->a->repeatForever = 1;
 		} else {
+			time_t tmptime = local->ical->recur->_enddate - 86400; 
 			local->a->repeatForever = 0;
-			local->a->repeatEnd = *localtime(&local->ical->recur->_enddate);
+			local->a->repeatEnd = *localtime(&tmptime);
 		}
 		local->a->repeatFrequency = local->ical->recur->interval; 
 
@@ -1038,7 +1061,7 @@ transmit (GnomePilotConduitStandardAbs *conduit,
 	p->record = g_new0(char,0xffff);
 	p->length = pack_Appointment(local->a,p->record,0xffff);
 
-#if 0
+#if DEBUG_CALCONDUIT
 	/* This is some debug code that hexdumps the calendar entry...
 	   You won't need this. */
 	{
@@ -1092,10 +1115,11 @@ compare (GnomePilotConduitStandardAbs *conduit,
 	int err;
 	int retval;
 
+#if 0
 	/* used by the tedious compare */
 	struct Appointment a; 
 	int daycount;
-
+#endif
 	g_message ("entering compare");
 
 	g_return_val_if_fail (local!=NULL,-1);
