@@ -27,6 +27,7 @@
 #include <errno.h>
 #include <unistd.h>
 #include <sys/stat.h>
+#include <libgnomeui/gnome-window-icon.h>
 
 #include <glib.h>
 #include <stdio.h>
@@ -712,6 +713,7 @@ void gnomecard_init(void)
 	gnomecard_init_stock();
 	gnomecard_init_pixes();
 	
+	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-gnomecard.png");
 	gnomecard_window = GNOME_APP(gnome_app_new("GnomeCard", 
 						   "GnomeCard: Default"));
 	x = gnome_config_get_int("/GnomeCard/CardDisplay/width=0");
